==> fannypack-2.2.0.tgz: package/es/Button/Button.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _templateObject = _taggedTemplateLiteralLoose(['\n  position: absolute;\n  width: 100%;\n  height: 100%;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n\n  & + span {\n    opacity: 0;\n  }\n'], ['\n  position: absolute;\n  width: 100%;\n  height: 100%;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n\n  & + span {\n    opacity: 0;\n  }\n']);

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _taggedTemplateLiteralLoose(strings, raw) { strings.raw = raw; return strings; }

import React from 'react';
import { withTheme } from 'reakit/styled';
import styled from 'reakit/styled';
import Box from 'reakit/Box';
import _get from 'lodash/get';

import Spinner from '../Spinner';
import _Button from './styled';

export var SpinnerWrapper = styled(Box)(_templateObject);

var Button = function Button(_ref) {
  var children = _ref.children,
      className = _ref.className,
      disabled = _ref.disabled,
      isLoading = _ref.isLoading,
      palette = _ref.palette,
      size = _ref.size,
      type = _ref.type,
      props = _objectWithoutProperties(_ref, ['children', 'className', 'disabled', 'isLoading', 'palette', 'size', 'type']);

  var themePalette = _get(props, 'theme.palette');
  return React.createElement(
    _Button,
    _extends({
      className: className,
      disabled: disabled,
      isLoading: isLoading,
      palette: palette,
      size: size,
      type: type
    }, props),
    isLoading ? React.createElement(
      SpinnerWrapper,
      null,
      React.createElement(Spinner, {
        color: type === 'default' ? themePalette[(palette || '') + 'Inverted'](props) : themePalette['' + (palette || '')]
      })
    ) : null,
    React.createElement(
      'span',
      null,
      children
    )
  );
};

export { Button };
Button.defaultProps = {
  as: null,
  className: null,
  disabled: false,
  isLoading: false,
  palette: 'default',
  size: 'default',
  type: 'default'
};

export var ThemedButton = withTheme(Button);

==> fannypack-2.8.0.tgz: package/es/Button/Button.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _templateObject = _taggedTemplateLiteralLoose(['\n  position: absolute;\n  width: 100%;\n  height: 100%;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n\n  & + span {\n    opacity: 0;\n  }\n'], ['\n  position: absolute;\n  width: 100%;\n  height: 100%;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n\n  & + span {\n    opacity: 0;\n  }\n']);

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _taggedTemplateLiteralLoose(strings, raw) { strings.raw = raw; return strings; }

import React from 'react';
import styled from 'reakit/styled';
import Box from 'reakit/Box';

import Spinner from '../Spinner';
import _Button from './styled';

export var SpinnerWrapper = styled(Box)(_templateObject);

var Button = function Button(_ref) {
  var children = _ref.children,
      className = _ref.className,
      disabled = _ref.disabled,
      isLoading = _ref.isLoading,
      palette = _ref.palette,
      size = _ref.size,
      type = _ref.type,
      props = _objectWithoutProperties(_ref, ['children', 'className', 'disabled', 'isLoading', 'palette', 'size', 'type']);

  return React.createElement(
    _Button,
    _extends({
      className: className,
      disabled: disabled,
      isLoading: isLoading,
      palette: palette,
      size: size,
      type: type
    }, props),
    isLoading ? React.createElement(
      SpinnerWrapper,
      null,
      React.createElement(Spinner, { color: type === 'default' ? (palette || '') + 'Inverted' : palette })
    ) : null,
    React.createElement(
      'span',
      null,
      children
    )
  );
};

export { Button };
Button.defaultProps = {
  as: null,
  className: null,
  disabled: false,
  isLoading: false,
  palette: 'default',
  size: 'default',
  type: 'default'
};

export default Button;
